@@ -1,3 +1,6 @@
+"""
+Tools to interact with hdf5 files and handle data consistently.
+"""
 from typing import Union
 import collections
 from itertools import groupby, chain, product
@@ -18,7 +21,7 @@ class BridgeH5:
         if flag is not None:
             self._hdf = h5py.File(filename, flag)
 
-            self._filecheck
+            self._filecheck()
 
     def _filecheck(self):
         assert "cell_info" in self._hdf, "Invalid file. No 'cell_info' found."
